import { Signal } from '@angular/core';
import { Observable } from 'rxjs';
/**
 * A `Signal` that can also be observed as an `Observable`.
 */
export interface ObservableSignal<Value, InitialValue = Value> extends Signal<Value | InitialValue> {
    /**
     * Observe the signal as an `Observable`.
     * The `Observable` will be lazily created and cached if possible.
     */
    observe(): Observable<Value>;
}
/**
 * Create an `ObservableSignal` from an synchronously `Observable`.
 */
export declare function toObservableSignal<Value>(observable: Observable<Value>): ObservableSignal<Value>;
/**
 * Create an `ObservableSignal` from an asynchronous `Observable` with an
 * initial value for the signal.
 */
export declare function toObservableSignal<Value, InitialValue>(initialValue: InitialValue, observable: Observable<Value>): ObservableSignal<Value, InitialValue>;
/**
 * Create an `ObservableSignal` from a `Signal`.
 */
export declare function toObservableSignal<Value>(signal: Signal<Value>): ObservableSignal<Value>;
