import { AbstractType } from '@angular/core';
import { OperatorFunction } from 'rxjs';
/**
 * RxJS operator that picks only the values that are instances
 * of the provided types.
 *
 * @example
 *  ```ts
 *  router.events.pipe(
 *    pickType(NavigationStart, NavigationEnd)
 *  ).subscribe(console.log);
 *  ```
 */
export declare const pickType: <Types extends AbstractType<any>[]>(...types: Types) => OperatorFunction<unknown, Types[number]["prototype"]>;
/**
 * RxJS operator that maps values to `undefined`.
 * Useful when an `Observable<void>` type is expected.
 *
 * @remarks Shorthand for `map(() => undefined)`.
 *
 * @example
 * ```ts
 * const void$: Observable<void> = router.events.pipe(
 *   tap((v) => console.log(v)),
 *   mapToVoid(),
 * );
 * ```
 */
export declare const mapToVoid: () => OperatorFunction<unknown, void>;
